# -*- coding: iso-8859-1 -*-

"""
    MoinMoin - MercurialWiki theme
    @copyright: 2009, 2010 Paul Boddie <paul@boddie.org.uk>
    @copyright: (portions) 2003-2008 MoinMoin:ThomasWaldmann, 2003-2005 Nir Soffer
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin.theme import ThemeBase
from MoinMoin import i18n
from MoinMoin import wikiutil
from MoinMoin import version
from MoinMoin.Page import Page
import re

class Theme(ThemeBase):

    name = "mercurialwiki"

    # Icon definitions from the modernized theme...

    _ = lambda x: x     # We don't have gettext at this moment, so we fake it
    icons = {
        # key         alt                        icon filename      w   h
        # FileAttach
        'attach':     ("%(attach_count)s",       "moin-attach.png",   16, 16),
        'info':       ("[INFO]",                 "moin-info.png",     16, 16),
        'attachimg':  (_("[ATTACH]"),            "attach.png",        32, 32),
        # RecentChanges
        'rss':        (_("[RSS]"),               "moin-rss.png",      16, 16),
        'deleted':    (_("[DELETED]"),           "moin-deleted.png",  16, 16),
        'updated':    (_("[UPDATED]"),           "moin-updated.png",  16, 16),
        'renamed':    (_("[RENAMED]"),           "moin-renamed.png",  16, 16),
        'conflict':   (_("[CONFLICT]"),          "moin-conflict.png", 16, 16),
        'new':        (_("[NEW]"),               "moin-new.png",      16, 16),
        'diffrc':     (_("[DIFF]"),              "moin-diff.png",     16, 16),
        # General
        'bottom':     (_("[BOTTOM]"),            "moin-bottom.png",   16, 16),
        'top':        (_("[TOP]"),               "moin-top.png",      16, 16),
        'www':        ("[WWW]",                  "moin-www.png",      16, 16),
        'mailto':     ("[MAILTO]",               "moin-email.png",    16, 16),
        'news':       ("[NEWS]",                 "moin-news.png",     16, 16),
        'telnet':     ("[TELNET]",               "moin-telnet.png",   16, 16),
        'ftp':        ("[FTP]",                  "moin-ftp.png",      16, 16),
        'file':       ("[FILE]",                 "moin-ftp.png",      16, 16),
        # search forms
        'searchbutton': ("[?]",                  "moin-search.png",   16, 16),
        'interwiki':  ("[%(wikitag)s]",          "moin-inter.png",    16, 16),

        # smileys (this is CONTENT, but good looking smileys depend on looking
        # adapted to the theme background color and theme style in general)
        #vvv    ==      vvv  this must be the same for GUI editor converter
        'X-(':        ("X-(",                    'angry.png',         16, 16),
        ':D':         (":D",                     'biggrin.png',       16, 16),
        '<:(':        ("<:(",                    'frown.png',         16, 16),
        ':o':         (":o",                     'redface.png',       16, 16),
        ':(':         (":(",                     'sad.png',           16, 16),
        ':)':         (":)",                     'smile.png',         16, 16),
        'B)':         ("B)",                     'smile2.png',        16, 16),
        ':))':        (":))",                    'smile3.png',        16, 16),
        ';)':         (";)",                     'smile4.png',        16, 16),
        '/!\\':       ("/!\\",                   'alert.png',         16, 16),
        '<!>':        ("<!>",                    'attention.png',     16, 16),
        '(!)':        ("(!)",                    'idea.png',          16, 16),
        ':-?':        (":-?",                    'tongue.png',        16, 16),
        ':\\':        (":\\",                    'ohwell.png',        16, 16),
        '>:>':        (">:>",                    'devil.png',         16, 16),
        '|)':         ("|)",                     'tired.png',         16, 16),
        ':-(':        (":-(",                    'sad.png',           16, 16),
        ':-)':        (":-)",                    'smile.png',         16, 16),
        'B-)':        ("B-)",                    'smile2.png',        16, 16),
        ':-))':       (":-))",                   'smile3.png',        16, 16),
        ';-)':        (";-)",                    'smile4.png',        16, 16),
        '|-)':        ("|-)",                    'tired.png',         16, 16),
        '(./)':       ("(./)",                   'checkmark.png',     16, 16),
        '{OK}':       ("{OK}",                   'thumbs-up.png',     16, 16),
        '{X}':        ("{X}",                    'icon-error.png',    16, 16),
        '{i}':        ("{i}",                    'icon-info.png',     16, 16),
        '{1}':        ("{1}",                    'prio1.png',         15, 13),
        '{2}':        ("{2}",                    'prio2.png',         15, 13),
        '{3}':        ("{3}",                    'prio3.png',         15, 13),
        '{*}':        ("{*}",                    'star_on.png',       16, 16),
        '{o}':        ("{o}",                    'star_off.png',      16, 16),
    }
    del _

    def header(self, d, **kw):
        """ Assemble page header

        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """

        request = self.request
        fmt = request.formatter
        html = []

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        show_section_numbers = fmt._show_section_numbers
        fmt._show_section_numbers = 0

        # The header section.

        html.append(fmt.div(on=1, attr={"id" : "header"}))

        html.append(self.logo())

        html.append(fmt.div(on=1, attr={"class" : "controls"}))
        html.append(self.navibar(d).strip())
        html.append(self.searchform(d).strip())
        html.append(fmt.div(on=0))

        # A separator.

        html.append(fmt.div(on=1, attr={"class" : "pageline"}))
        html.append(fmt.div(on=0))

        html.append(self.username(d))

        html.append(fmt.div(on=0))

        # Show any pertinent message.

        html.append(self.msg(d))

        # Complete the header.

        html.append(self.startPage())

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        fmt._show_section_numbers = show_section_numbers

        return u''.join(html)

    editorheader = header

    def footer(self, d, **kw):
        """ Assemble page footer

        @param d: parameter dictionary
        @rtype: unicode
        @return: page footer html
        """

        request = self.request
        fmt = request.formatter
        _ = request.getText
        page = d["page"]
        html = []

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        show_section_numbers = fmt._show_section_numbers
        fmt._show_section_numbers = 0

        # End the page.

        html.append(self.endPage())

        # The footer section.

        html.append(fmt.div(on=1, attr={"id" : "footer"}))

        if self.shouldShowEditbar(page):
            html.append(fmt.div(on=1, attr={"class" : "controls"}))
            html.append(self.editbar(d))
            html.append(fmt.div(on=0))

        # A separator.

        html.append(fmt.div(on=1, attr={"class" : "pageline"}))
        html.append(fmt.div(on=0))

        html.append(self.credits(d))

        #html.append(self.trail(d))

        html.append(fmt.div(on=0))

        # NOTE: Some pages cause section numbers to be enabled, affecting the
        # NOTE: theme.

        fmt._show_section_numbers = show_section_numbers

        return u''.join(html)

    def actionsMenu(self, page):

        """ An overridden version of the actions menu

        This method strips the adjacent white-space from the generated menu.

        @param page: current page, Page object
        @rtype: unicode
        @return: actions menu html fragment
        """

        return ThemeBase.actionsMenu(self, page).strip()

# Theme instantiation.

def execute(request):
    """
    Generate and return a theme object

    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

# vim: tabstop=4 expandtab shiftwidth=4
